!function(e){const t=e.nb=e.nb||{};t.dictionary=Object.assign(t.dictionary||{},{"%0 of %1":"","Align cell text to the bottom":"","Align cell text to the center":"","Align cell text to the left":"","Align cell text to the middle":"","Align cell text to the right":"","Align cell text to the top":"","Align center":"Midstill","Align left":"Venstrejuster","Align right":"Høyrejuster","Align table to the left":"","Align table to the right":"",Alignment:"",Aquamarine:"",Background:"",Big:"Stor",Black:"","Block quote":"Blokksitat",Blue:"","Blue marker":"Blå uthevingsfarge",Bold:"Fet",Border:"","Break text":"","Bulleted List":"Punktmerket liste","Bulleted list styles toolbar":"",Cancel:"Avbryt","Cannot upload file:":"Kan ikke laste opp fil:","Caption for image: %0":"","Caption for the image":"","Cell properties":"","Center table":"","Centered image":"Midtstilt bilde","Change image text alternative":"Endre tekstalternativ for bilde","Choose heading":"Velg overskrift",Circle:"",Code:"Kode",Color:"","Color picker":"",Column:"Kolonne",Dashed:"",Decimal:"","Decimal with leading zero":"",Default:"Standard","Delete column":"Slett kolonne","Delete row":"Slett rad","Dim grey":"",Dimensions:"",Disc:"","Document colors":"",Dotted:"",Double:"",Downloadable:"","Dropdown toolbar":"","Edit block":"","Edit link":"Rediger lenke","Editor editing area: %0":"","Editor toolbar":"","Enter image caption":"Skriv inn bildetekst","Font Background Color":"","Font Color":"","Font Family":"Skrifttype","Font Size":"Skriftstørrelse","Full size image":"Bilde i full størrelse",Green:"","Green marker":"Grønn uthevingsfarge","Green pen":"Grønn penn",Grey:"",Groove:"","Header column":"Overskriftkolonne","Header row":"Overskriftrad",Heading:"Overskrift","Heading 1":"Overskrift 1","Heading 2":"Overskrift 2","Heading 3":"Overskrift 3","Heading 4":"","Heading 5":"","Heading 6":"",Height:"",Highlight:"Utheving","Horizontal text alignment toolbar":"",Huge:"Veldig stor","Image resize list":"","Image toolbar":"","image widget":"Bilde-widget","In line":"",Insert:"","Insert column left":"","Insert column right":"","Insert image":"Sett inn bilde","Insert image via URL":"","Insert row above":"Sett inn rad over","Insert row below":"Sett inn rad under","Insert table":"Sett inn tabell",Inset:"",Italic:"Kursiv",Justify:"Blokkjuster","Justify cell text":"","Left aligned image":"Venstrejustert bilde","Light blue":"","Light green":"","Light grey":"",Link:"Lenke","Link URL":"URL for lenke","List properties":"","Lower-latin":"","Lower–roman":"","Merge cell down":"Slå sammen celle ned","Merge cell left":"Slå sammen celle til venstre","Merge cell right":"Slå sammen celle til høyre","Merge cell up":"Slå sammen celle opp","Merge cells":"Slå sammen celler",Next:"",None:"","Numbered List":"Nummerert liste","Numbered list styles toolbar":"","Open in a new tab":"","Open link in new tab":"Åpne lenke i ny fane",Orange:"",Original:"",Outset:"",Padding:"",Paragraph:"Avsnitt","Pink marker":"Rosa uthevingsfarge",Previous:"",Purple:"",Red:"","Red pen":"Rød penn",Redo:"Gjør om","Remove color":"","Remove highlight":"Fjern uthevingsfarge","Resize image":"","Resize image to %0":"","Resize image to the original size":"","Restore default":"","Reversed order":"","Rich Text Editor":"Rikteksteditor",Ridge:"","Right aligned image":"Høyrejustert bilde",Row:"Rad",Save:"Lagre","Select column":"","Select row":"","Show more items":"","Side image":"Sidebilde",Small:"Liten",Solid:"","Split cell horizontally":"Del celle horisontalt","Split cell vertically":"Del celle vertikalt",Square:"","Start at":"","Start index must be greater than 0.":"",Strikethrough:"Gjennomstreking",Style:"",Subscript:"",Superscript:"","Table alignment toolbar":"","Table cell text alignment":"","Table properties":"","Table toolbar":"","Text alignment":"Tekstjustering","Text alignment toolbar":"","Text alternative":"Tekstalternativ for bilde","Text highlight toolbar":"",'The color is invalid. Try "#FF0000" or "rgb(255,0,0)" or "red".':"",'The value is invalid. Try "10px" or "2em" or simply "2".':"","This link has no URL":"Denne lenken har ingen URL",Tiny:"Veldig liten","To-do List":"","Toggle caption off":"","Toggle caption on":"","Toggle the circle list style":"","Toggle the decimal list style":"","Toggle the decimal with leading zero list style":"","Toggle the disc list style":"","Toggle the lower–latin list style":"","Toggle the lower–roman list style":"","Toggle the square list style":"","Toggle the upper–latin list style":"","Toggle the upper–roman list style":"",Turquoise:"",Underline:"Understreking",Undo:"Angre",Unlink:"Fjern lenke",Update:"","Update image URL":"","Upload failed":"Opplasting feilet","Upload in progress":"Opplasting pågår","Upper-latin":"","Upper-roman":"","Vertical text alignment toolbar":"",White:"",Width:"","Wrap text":"",Yellow:"","Yellow marker":"Gul uthevingsfarge"}),t.getPluralForm=function(e){return 1!=e}}(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));